#!/bin/sh

# The script should be able to run under busybox shell.

set -e

BASE_DIR="$(dirname "$0")"

MEDIASERVER_BINARY="${BASE_DIR}/../../bin/mediaserver"
LIB_DIR="${BASE_DIR}/.."
FALLBACK_LIB_DIR="${BASE_DIR}"

createFallbackLibSymlink()
{
    LIB_NAME="$1" && shift

    # Get ld.so path from the mediaserver binary.

    # Try to use "file" tool to get the file info. On some systems, "file" may not be available; in
    # such cases try "strings" tool instead.
    FILE_INFO_TOOL="file"
    if ! which "${FILE_INFO_TOOL}" >/dev/null 2>&1; then
        FILE_INFO_TOOL="strings"
    fi

    INTERPRETER_PATH="$("${FILE_INFO_TOOL}" "${MEDIASERVER_BINARY}" \
        | grep -m1 -Eo '/[^\s]*ld-linux[^\s]*\.so[.0-9]*')"
    if [ -f "${INTERPRETER_PATH}" ]; then
        # Use it to check for existence of the library with an appropriate architecture.
        # `--list` is to avoid execution of the specified library.
        "${INTERPRETER_PATH}" --list "${LIB_NAME}" >/dev/null 2>&1 && return
    fi

    ln -sf "$(realpath "${FALLBACK_LIB_DIR}/${LIB_NAME}")" "${LIB_DIR}/${LIB_NAME}"
}

createFallbackLibSymlinks()
{
    for lib in $(cat "${FALLBACK_LIB_DIR}/libs.txt"); do
        createFallbackLibSymlink "${lib}"
    done
}

removeFallbackLibSymlinks()
{
    for lib in $(cat "${FALLBACK_LIB_DIR}/libs.txt"); do
        rm -f "${LIB_DIR}/${lib}"
    done
}

if [ "$1" = "create" ]; then
    createFallbackLibSymlinks
elif [ "$1" = "remove" ]; then
    removeFallbackLibSymlinks
else # Recreate symlinks by default.
    removeFallbackLibSymlinks
    createFallbackLibSymlinks
fi
